pub struct GuardRegistration<'a, T> { /* private fields */ }Expand description
Safe api for creating self reference between a pinned ValueGuard and
RefGuard pair.
This can be acquired with
ValueGuard::registration().
Implementations
Sourceimpl<'a, T> GuardRegistration<'a, T>
impl<'a, T> GuardRegistration<'a, T>
Sourcepub fn register(self, slot: Pin<&'a RefGuard<T>>)
pub fn register(self, slot: Pin<&'a RefGuard<T>>)
Binds a provided slot to the self.value_guard.
This means they will reference each other, and will invalidate their references to each other when dropped.
This method also invalidates the existing references held by the
now-replaced referencees of slot and self.value_guard to avoid
dangling pointers.