RefGuard

Struct RefGuard 

pub struct RefGuard<T> { /* private fields */ }
Weak guard for acquiring read only access to a ValueGuard’s value.

Safety

This struct must not be leaked to the stack using mem::forget or any other mechanism that causes the contents of Self to be overwritten without Drop::drop() running. Doing so creates unsoundness that likely will lead to dereferencing a null pointer.

Note that it is sound to leak Self to the heap using methods including Box::leak() because heap allocated data will never be overwritten if it is never freed.

Implementations

Source

impl<T> RefGuard<T>

pub fn new() -> Self

Creates a new RefGuard with no reference to a ValueGuard.

Source

impl<T: Copy> RefGuard<T>

pub fn get(&self) -> Option<T>

Gets a copy of the value stored inside the ValueGuard this RefGuard references.